@@ -5,6 +5,8 @@ import collections
 import re
 from typing import List, Optional, overload
 
+from specfile.types import SupportsIndex
+
 # valid section names as defined in build/parseSpec.c in RPM source
 SECTION_NAMES = {
     "package",
@@ -59,7 +61,7 @@ class Section(collections.UserList):
 
     def __init__(self, name: str, data: Optional[List[str]] = None) -> None:
         super().__init__()
-        if not name or name.split()[0] not in SECTION_NAMES:
+        if not name or name.split()[0].lower() not in SECTION_NAMES:
             raise ValueError(f"Invalid section name: '{name}'")
         self.name = name
         if data is not None:
@@ -79,7 +81,7 @@ class Section(collections.UserList):
         return Section(self.name, self.data)
 
     @overload
-    def __getitem__(self, i: int) -> str:
+    def __getitem__(self, i: SupportsIndex) -> str:
         pass
 
     @overload
@@ -127,13 +129,15 @@ class Sections(collections.UserList):
         return Sections(self.data)
 
     def __getattr__(self, name: str) -> Section:
+        if name.split()[0].lower() not in SECTION_NAMES:
+            return super().__getattribute__(name)
         try:
-            return self.data[self.find(name)]
+            return self.get(name)
         except ValueError:
             raise AttributeError(name)
 
     def __setattr__(self, name: str, value: List[str]) -> None:
-        if name.split()[0] not in SECTION_NAMES:
+        if name.split()[0].lower() not in SECTION_NAMES:
             return super().__setattr__(name, value)
         try:
             self.data[self.find(name)].data = value
@@ -141,16 +145,20 @@ class Sections(collections.UserList):
             raise AttributeError(name)
 
     def __delattr__(self, name: str) -> None:
-        if name.split()[0] not in SECTION_NAMES:
+        if name.split()[0].lower() not in SECTION_NAMES:
             return super().__delattr__(name)
         try:
             del self.data[self.find(name)]
         except ValueError:
             raise AttributeError(name)
 
+    def get(self, name: str) -> Section:
+        return self.data[self.find(name)]
+
     def find(self, name: str) -> int:
+        name = name.lower()
         for i, section in enumerate(self.data):
-            if section.name == name:
+            if section.name.lower() == name:
                 return i
         raise ValueError
 
@@ -166,7 +174,7 @@ class Sections(collections.UserList):
             Constructed instance of `Sections` class.
         """
         section_name_regexes = [
-            re.compile(rf"^%{re.escape(n)}\b.*") for n in SECTION_NAMES
+            re.compile(rf"^%{re.escape(n)}\b.*", re.IGNORECASE) for n in SECTION_NAMES
         ]
         section_starts = []
         lines = s.splitlines()
