@@ -6,6 +6,7 @@ import re
 from typing import Any, Iterable, List, Optional, Union, overload
 
 from specfile.sections import Section
+from specfile.types import SupportsIndex
 
 # valid tag names extracted from lib/rpmtag.h in RPM source
 TAG_NAMES = {
@@ -334,7 +335,7 @@ class Comments(collections.UserList):
         return item in self.data
 
     @overload
-    def __getitem__(self, i: int) -> Comment:
+    def __getitem__(self, i: SupportsIndex) -> Comment:
         pass
 
     @overload
@@ -348,7 +349,7 @@ class Comments(collections.UserList):
             return self.data[i]
 
     @overload
-    def __setitem__(self, i: int, item: Union[Comment, str]) -> None:
+    def __setitem__(self, i: SupportsIndex, item: Union[Comment, str]) -> None:
         pass
 
     @overload
@@ -461,6 +462,17 @@ class Tag:
         self._separator = separator
         self.comments = comments.copy()
 
+    def __eq__(self, other: object) -> bool:
+        if not isinstance(other, Tag):
+            return NotImplemented
+        return (
+            self.name == other.name
+            and self.value == other.value
+            and self._expanded_value == other._expanded_value
+            and self._separator == other._separator
+            and self.comments == other.comments
+        )
+
     def __repr__(self) -> str:
         comments = repr(self.comments)
         return (
@@ -523,7 +535,7 @@ class Tags(collections.UserList):
         return f"Tags({data}, {remainder})"
 
     @overload
-    def __getitem__(self, i: int) -> Tag:
+    def __getitem__(self, i: SupportsIndex) -> Tag:
         pass
 
     @overload
@@ -537,6 +549,8 @@ class Tags(collections.UserList):
             return self.data[i]
 
     def __getattr__(self, name: str) -> Tag:
+        if name.capitalize().rstrip("0123456789") not in TAG_NAMES:
+            return super().__getattribute__(name)
         try:
             return self.data[self.find(name)]
         except ValueError:
